News
====

Lists of changes between versions.

Latest
------
* Major:
* Minor:
* Patch:

0.1.0
-----
* Minor: Added checks during release

0.0.5
-----

* Minor: Added security vulnerabilities check using 'safety'.
* Minor: Added docstrings check using 'flake8-docstrings'.
* Minon: Git releated functionality moved to bouillon.git.*

0.0.1
-----
* Initial release.
